==> nextcloud-23.0.8.tgz: nextcloud/apps/dashboard/l10n/nb.js <==
OC.L10N.register(
    "dashboard",
    {
    "Dashboard" : "Instrumentpanel",
    "Dashboard app" : "Instrumentpanel app",
    "Start your day informed\n\nThe Nextcloud Dashboard is your starting point of the day, giving you an\noverview of your upcoming appointments, urgent emails, chat messages,\nincoming tickets, latest tweets and much more! Users can add the widgets\nthey like and change the background to their liking." : "Start dagen din informert \n\nNextcloud skrivebordet er starte punktet ditt for dagen, gir deg kommende møter, viktig email, chat-meldinger\ninnkommende biletter, seneste tweets og mye mer! Brukere kan legge til widgeter\nde liker og forandre bakgrunnen etter deres smak.",
    "Customize" : "Tilpass",
    "Edit widgets" : "Rediger widgets",
    "Get more widgets from the App Store" : "Få flere widgets fra App Store",
    "Change background image" : "Endre bakgrunnsbilde",
    "Weather service" : "Værmelding",
    "For your privacy, the weather data is requested by your Nextcloud server on your behalf so the weather service receives no personal information." : "Av hensyn til personvernet ditt blir værdataene bedt om av Nextcloud-serveren din på dine vegne, slik at værtjenesten ikke mottar personlig informasjon.",
    "Weather data from Met.no" : "Værmelding fra Met.no",
    "geocoding with Nominatim" : "geokoding med Nominatim",
    "elevation data from OpenTopoData" : "høydedata fra OpenTopoData",
    "Weather" : "Vær",
    "Status" : "Status",
    "Good morning" : "God morgen",
    "Good morning, {name}" : "God morgen, {name}",
    "Good afternoon" : "God ettermiddag",
    "Good afternoon, {name}" : "Good ettermiddag, {name}",
    "Good evening" : "God kveld",
    "Good evening, {name}" : "God kveld, {name}",
    "Hello" : "Hallo",
    "Hello, {name}" : "Hallo, {name}",
    "Pick from Files" : "Velg fra Filer",
    "Default images" : "Standardbilde",
    "Plain background" : "Ensfarget bakgrunn",
    "Insert from {productName}" : "Sett inn fra {productName}",
    "Show something" : "Vis noe"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-23.0.9.tgz: nextcloud/apps/dashboard/l10n/nb.js <==
OC.L10N.register(
    "dashboard",
    {
    "Dashboard" : "Instrumentpanel",
    "Dashboard app" : "Instrumentpanel app",
    "Start your day informed\n\nThe Nextcloud Dashboard is your starting point of the day, giving you an\noverview of your upcoming appointments, urgent emails, chat messages,\nincoming tickets, latest tweets and much more! Users can add the widgets\nthey like and change the background to their liking." : "Start dagen din informert \n\nNextcloud skrivebordet er starte punktet ditt for dagen, gir deg kommende møter, viktig email, chat-meldinger\ninnkommende biletter, seneste tweets og mye mer! Brukere kan legge til widgeter\nde liker og forandre bakgrunnen etter deres smak.",
    "Customize" : "Tilpass",
    "Edit widgets" : "Rediger widgets",
    "Get more widgets from the App Store" : "Få flere widgets fra App Store",
    "Change background image" : "Endre bakgrunnsbilde",
    "Weather service" : "Værmelding",
    "For your privacy, the weather data is requested by your Nextcloud server on your behalf so the weather service receives no personal information." : "Av hensyn til personvernet ditt blir værdataene bedt om av Nextcloud-serveren din på dine vegne, slik at værtjenesten ikke mottar personlig informasjon.",
    "Weather data from Met.no" : "Værmelding fra Met.no",
    "geocoding with Nominatim" : "geokoding med Nominatim",
    "elevation data from OpenTopoData" : "høydedata fra OpenTopoData",
    "Weather" : "Vær",
    "Status" : "Status",
    "Good morning" : "God morgen",
    "Good morning, {name}" : "God morgen, {name}",
    "Good afternoon" : "God ettermiddag",
    "Good afternoon, {name}" : "Good ettermiddag, {name}",
    "Good evening" : "God kveld",
    "Good evening, {name}" : "God kveld, {name}",
    "Hello" : "Hallo",
    "Hello, {name}" : "Hallo, {name}",
    "Pick from Files" : "Velg fra Filer",
    "Plain background" : "Ensfarget bakgrunn",
    "Insert from {productName}" : "Sett inn fra {productName}",
    "Show something" : "Vis noe",
    "Default images" : "Standardbilde"
},
"nplurals=2; plural=(n != 1);");
